# CI App Python Tracer Feature Tracking 

## Description:

The `ci-app-spec.json` file tracks the CI App features supported by 
the tracer, currently for pytest spans. This file is then
used in the [datadog-ci-spec](https://github.com/DataDog/datadog-ci-spec/blob/main/.github/workflows/feature-track.yml) 
repository. 
